@@ -5,7 +5,10 @@ check.dist <- function(sp, pp,
     if (!inherits(pp, "phreg")) stop ("Second argument must be of type 'phreg'")
 
     plot.phreg(pp, fn = "cum", fig = TRUE, new.data = new.data)
-    x <- plot.coxreg(sp, fn = "cum", fig = FALSE, new.data = new.data)$x[[1]]
-    lines(x[, 1], x[, 2], type = "s", lty = 2, col = "red")
+    x <- plot.coxreg(sp, fn = "cum", fig = FALSE, new.data = new.data)$x
+    for (rr in 1:length(x)){
+        xx <- x[[rr]]
+        lines(xx[, 1], xx[, 2], type = "s", lty = 2, col = "red")
+    }
 }
 
